package envoy.server.processors;

import java.io.IOException;

import envoy.event.GroupResizeEvent;
import envoy.server.data.Contact;
import envoy.server.data.PersistenceManager;
import envoy.server.net.ConnectionManager;
import envoy.server.net.ObjectWriteProxy;

/**
 * Project: <strong>envoy-server-standalone</strong><br>
 * File: <strong>GroupResizeProcessor.java</strong><br>
 * Created: <strong>03.04.2020</strong><br>
 *
 * @author Maximilian K&auml;fer
 * @since Envoy Server Standalone v0.1-beta
 */
public class GroupResizeProcessor implements ObjectProcessor<GroupResizeEvent> {

	PersistenceManager	persistenceManager	= PersistenceManager.getInstance();
	ConnectionManager	connectionManager	= ConnectionManager.getInstance();

	@Override
	public void process(GroupResizeEvent input, long socketID, ObjectWriteProxy writeProxy) throws IOException {
		envoy.server.data.Group group = persistenceManager.getGroupByID(input.getGroupID());
		switch (input.getOperation()) {
			case ADD:
				group.getContacts().add(persistenceManager.getUserByID(input.get()));
				break;

			case REMOVE:
				group.getContacts().remove(persistenceManager.getUserByID(input.get()));
				break;
		}
		persistenceManager.updateContact(group);
		writeProxy.write(socketID, group);
		group.getContacts()
			.stream()
			.map(Contact::getID)
			.filter(connectionManager::isOnline)
			.map(connectionManager::getSocketId)
			.forEach(memberSocketID -> {
				try {
					writeProxy.write(memberSocketID, group);
				} catch (IOException e) {
					e.printStackTrace();
				}
			});
	}

	@Override
	public Class<GroupResizeEvent> getInputClass() { return GroupResizeEvent.class; }
}
